@@ -43,13 +43,13 @@ The only onterface function is iter_avro, example usage::
         writer(out, schema, records)
 '''
 
-__version_info__ = (0, 16, 7)
+__version_info__ = (0, 17, 0)
 __version__ = '%s.%s.%s' % __version_info__
 
 
-from . import reader as _reader
-from . import writer as _writer
-from . import schema as _schema
+import fastavro.read
+import fastavro.write
+import fastavro.schema
 
 
 def _acquaint_schema(schema):
@@ -60,19 +60,20 @@ def _acquaint_schema(schema):
     schema: dict
         Schema to add to repo
     """
-    _reader.acquaint_schema(schema)
-    _writer.acquaint_schema(schema)
+    fastavro.read.acquaint_schema(schema)
+    fastavro.write.acquaint_schema(schema)
 
 
-reader = iter_avro = _reader.iter_avro
-schemaless_reader = _reader.schemaless_reader
-load = _reader.read_data
-writer = _writer.writer
-schemaless_writer = _writer.schemaless_writer
-dump = _writer.dump
+reader = iter_avro = fastavro.read.iter_avro
+schemaless_reader = fastavro.read.schemaless_reader
+load = fastavro.read.read_data
+writer = fastavro.write.writer
+schemaless_writer = fastavro.write.schemaless_writer
+dump = fastavro.write.dump
+acquaint_schema = fastavro.schema.acquaint_schema
 acquaint_schema = _acquaint_schema
-_schema.acquaint_schema = _acquaint_schema
-is_avro = _reader.is_avro
+fastavro.schema.acquaint_schema = _acquaint_schema
+is_avro = fastavro.read.is_avro
 
 __all__ = [
     n for n in locals().keys() if not n.startswith('_')
